@@ -85,7 +85,7 @@ class SkillResponse(SkillResponseType):
     attach: None = None  # TODO: Отправка изображений, звуков, карт
 
     client_app_action: str or None = None
-    request_field_code: str or None = None
+    requested_field_code: str or None = None
 
     context: dict or None = field(default_factory=dict)
     redirect_to: str or None = None
@@ -114,7 +114,7 @@ class SkillResponse(SkillResponseType):
             choices=data.get('choices'),
             attach=None,
             client_app_action=data.get('client_app_action'),
-            request_field_code=data.get('request_field_code'),
+            requested_field_code=data.get('requested_field_code'),
             context=data.get('context'),
             redirect_to=data.get('redirect_to')
         )
@@ -162,7 +162,7 @@ class SkillResponse(SkillResponseType):
             "out_text": self.out_text,
             "choices": self.choices,
             "client_app_action": self.client_app_action,
-            "request_field_code": self.request_field_code,
+            "requested_field_code": self.requested_field_code,
             "context": self.context,
             "redirect_to": self.redirect_to
         }
